@@ -12,17 +12,19 @@
 # limitations under the License.
 
 import os
-import pkg_resources
 import uuid
 
 from pifpaf import drivers
 
+import pkg_resources
+
 
 class CephDriver(drivers.Driver):
     DEFAULT_PORT = 6790
 
     def __init__(self, port=DEFAULT_PORT,
                  **kwargs):
+        """Create a new Ceph cluster."""
         super(CephDriver, self).__init__(**kwargs)
         self.port = port
 
@@ -121,8 +123,6 @@ mon addr = 127.0.0.1:%(port)d
             mon_opts,
             wait_for_line=r"mon.a@0\(leader\).mds e1 print_map")
 
-        self.addCleanup(self._kill, mon)
-
         # Create and start OSD
         self._exec(ceph_opts + ["osd", "create"])
         self._exec(ceph_opts + ["osd", "crush", "add", "osd.0", "1",
@@ -133,7 +133,6 @@ mon addr = 127.0.0.1:%(port)d
         else:
             wait_for_line = "done with init"
         osd, _ = self._exec(osd_opts, wait_for_line=wait_for_line)
-        self.addCleanup(self._kill, osd)
 
         # Wait it's ready
         out = b""
